
// (c) COPYRIGHT URI/MIT 1996, 1999

// Please read the full copyright statement in the file COPYRIGHT.
//
// Authors:
//      Dan Holloway <d.holloway@gso.uri.edu> dan

// Implementation for JGStr. See JGByte.cc
//
// jhrg 1/12/95

#include "config_jg.h"

#ifdef __GNUG__
#pragma implementation
#endif

#include "debug.h"

#include "Error.h"
#include "jgofs.h"
#include "JGStr.h"

Str *
NewStr(const string &n)
{
    return new JGStr(n);
}

JGStr::JGStr(const string &n) : Str(n)
{
    _missing_val = "nd";
}

BaseType *
JGStr::ptr_duplicate()
{
    return new JGStr(*this);
}

bool
JGStr::read(const string &dataset)
{
    for (int j = 0; j < nVars; ++j) {
	if (name() == varName[j]) {
	    DBG(cerr << "Loaded " << varValue[j] << " into " << name() \
		<< endl);
	    string *value = new string(varValue[j]);
	    val2buf(value);
	    set_read_p(true);
	    return true;
	}
    }

    // If we get here then the variable was not found.
    string s = (string)"Variable " + name() 
      + "  wasn't located in JGOFS object " + dataset + ".";
    throw Error(unknown_error, s);
}

string
JGStr::get_missing_value() const
{
    return _missing_val;
}

void
JGStr::set_missing_value(const string &v)
{
    _missing_val = v;
}

// $Log: JGStr.cc,v $
// Revision 1.14.4.2  2001/08/21 15:15:26  dan
// Updated names of the set/get accessor methods for modifying the missing_value
// member field, to make the naming convention consistent with the current
// DAP usage.
//
// Revision 1.14.4.1  2001/05/31 19:14:01  dan
// Modified return value from read method, now returns true.
//
// Revision 1.14  2000/10/10 23:36:14  jimg
// Added exception processing code.
// Added throws to the read methods.
// Changed the definition of read to match the dap library.
// Moved CVS Log entries to the end of files.
//
// Revision 1.13  1999/11/05 01:17:24  jimg
// Result of merge with release-3-1-0
//
// Revision 1.12.6.1  1999/10/24 18:32:41  dan
// Modified to support new missing_value attribute
// handling.
//
// Revision 1.12  1999/05/05 04:38:00  brent
// convert String.h code to new stanard lib <string>
//
// Revision 1.11  1998/08/06 16:32:36  jimg
// Fixed misuse of the read(...) member function. Return true if more data
// is to be read, false is if not and error if an error is detected
//
// Revision 1.10  1998/07/24 21:40:25  jimg
// Removed errant #define DODS_DEBUG 1 line.
//
// Revision 1.9  1998/02/05 20:14:34  jimg
// DODS now compiles with gcc 2.8.x
//
// Revision 1.8  1996/11/12 16:55:22  jimg
// Added config_jg.h include
//
// Revision 1.7  1996/09/17 00:02:02  jimg
// Misc changes associated with merging branch code to the trunk.
//
// Revision 1.6.2.1.2.1  1996/06/26 22:18:04  jimg
// Dans changes for 2.05.
//
// Revision 1.4  1995/10/11  23:06:14  jimg
// These files are the result of merging Dan's changes into the main
// trunk. However, the archive was messed up in the process, so it may be hard
// to trace back to the original versions of some of these files.
//
// Revision 1.3.2.1.2.1  1995/10/02  18:12:05  jimg
// Merged modifications from Dan back into release version. CVS weirdness...
//
// Revision 1.3.2.1  1995/09/18  22:48:01  jimg
// Merged Dan's changes with the trunk version. This will be commited to the
// release-1-0-patches branch and then merged back into the trunk later.
//
// Revision 1.3  1995/07/09  21:39:54  jimg
// Added copyright notice.
//
// Revision 1.2  1995/03/14  01:17:08  jimg
// Modified JGStr::read() so that it works with the new Str class (which
// stores strings using a String object).
//
// Revision 1.1  1995/02/16  19:13:54  dan
// JGOFS sub-class definitions for Str.cc
//
// Revision 1.2  1995/01/19  21:59:03  jimg
// Added read_val from dummy_read.cc to the sample set of sub-class
// implementations.
// Changed the declaration of readVal in BaseType so that it names the
// mfunc read_val (to be consistant with the other mfunc names).
// Removed the unnecessary duplicate declaration of the abstract virtual
// mfuncs read and (now) read_val from the classes Byte, ... Grid. The
// declaration in BaseType is sufficient along with the decl and definition
// in the *.cc,h files which contain the subclasses for Byte, ..., Grid.
//
// Revision 1.1  1995/01/19  20:20:53  jimg
// Created as an example of subclassing the class hierarchy rooted at
// BaseType.
//
